import { Component, OnInit } from '@angular/core';
import {ActivatedRoute, Router} from '@angular/router';
import {TabuMiddlewareService} from '../dao/TabuMiddlewareService';
import {GameStatus} from '../interface/gameStatus';

@Component({
  selector: 'app-overview',
  templateUrl: './overview.component.html',
  styleUrls: ['./overview.component.scss']
})
export class OverviewComponent implements OnInit {
  nextTeam = '';
  team = '';
  buttonPlayDisabled = true;
  sessionName = '';
  membership = 'Wähle dein Team';
  gameStatus: GameStatus = {
    sessionID: -1,
    red: 0,
    blue: 0,
    redTurn: true,
    activeExplainer: false,
    activeWatchdog: false
  };

  constructor(private router: Router,
              private activatedRoute: ActivatedRoute,
              private service: TabuMiddlewareService) { }

  ngOnInit(): void {
    this.activatedRoute.paramMap.subscribe(params => {
      this.sessionName = String(params.get('sessionName'));
      this.team = String(params.get('team'));
      console.log('Team:', this.team);
      if (this.team === 'red'){
        this.membership = 'Du gehörst zu Team rot!';
        this.buttonPlayDisabled = false;
      }
      else if (this.team === 'blue'){
        this.membership = 'Du gehörst zu Team blau!';
        this.buttonPlayDisabled = false;
      }
      else if (this.team === 'null'){
        this.membership = 'Wähle dein Team';
      }
      else {
        this.router.navigate(['error']);
        return;
      }
      if (this.gameStatus.redTurn){
        this.nextTeam = 'Rot';
      }
      else{
        this.nextTeam = 'Blau';
      }
      this.service.getGamestatus({spielname: this.sessionName}).then(value => {
        const status = JSON.parse(value.status);
        if (status) {
          this.gameStatus.sessionID = JSON.parse(value.sessionID);
          this.gameStatus.red = JSON.parse(value.red);
          this.gameStatus.blue = JSON.parse(value.blue);
          this.gameStatus.redTurn = JSON.parse(value.redTurn);
          this.gameStatus.activeExplainer = JSON.parse(value.activeExplainer);
          this.gameStatus.activeWatchdog = JSON.parse(value.activeWatchdog);
        }
        console.log(this.gameStatus);
      }).catch(reason => console.log(reason));
    });
  }

  startGame(): void {
    if (this.team === 'red' || this.team === 'blue') {
      this.router.navigate([this.router.url + '/watchdog']);
    }
  }
  joinTeam(team: string): void {
    this.team = team;
    this.router.navigate([this.sessionName + '/' + team]);
  }
}
